"""This library generates pseudo-philosophical ramblings using a Markov chain."""
import markovify

corpus = """
If you want to achieve greatness stop asking for permission. Things work out best for those who make the best of how things work out. To live a creative life, we must lose our fear of being wrong. If you are not willing to risk the usual you will have to settle for the ordinary. Trust because you are willing to accept the risk, not because it's safe or certain. Take up one idea. Make that one idea your life - think of it, dream of it, live on that idea. Let the brain, muscles, nerves, every part of your body, be full of that idea, and just leave every other idea alone. This is the way to success. All our dreams can come true if we have the courage to pursue them. Good things come to people who wait, but better things come to those who go out and get them. If you do what you always did, you will get what you always got. Success is walking from failure to failure with no loss of enthusiasm. Just when the caterpillar thought the world was ending, he turned into a butterfly. Successful entrepreneurs are givers and not takers of positive energy. Whenever you see a successful person you only see the public glories, never the private sacrifices to reach them. Opportunities don't happen, you create them. Try not to become a person of success, but rather try to become a person of value. Great minds discuss ideas; average minds discuss events; small minds discuss people. I have not failed. I've just found 10,000 ways that won't work. If you don't value your time, neither will others. Stop giving away your time and talents- start charging for it. A successful man is one who can lay a firm foundation with the bricks others have thrown at him. No one can make you feel inferior without your consent. The whole secret of a successful life is to find out what is one's destiny to do, and then do it. If you're going through hell keep going. The ones who are crazy enough to think they can change the world, are the ones that do. Don't raise your voice, improve your argument. What seems to us as bitter trials are often blessings in disguise.~ Oscar Wilde. The meaning of life is to find your gift. The purpose of life is to give it away. The distance between insanity and genius is measured only by success. When you stop chasing the wrong things you give the right things a chance to catch you. Don't be afraid to give up the good to go for the great. No masterpiece was ever created by a lazy artist.~ Anonymous. Happiness is a butterfly, which when pursued, is always beyond your grasp, but which, if you will sit down quietly, may alight upon you. If you can't explain it simply, you don't understand it well enough. Blessed are those who can give without remembering and take without forgetting. Do one thing every day that scares you. What's the point of being alive if you don't at least try to do something remarkable. Life is not about finding yourself. Life is about creating yourself. Nothing in the world is more common than unsuccessful people with talent. Knowledge is being aware of what you can do. Wisdom is knowing when not to do it. Your problem isn't the problem. Your reaction is the problem. You can do anything, but not everything. Innovation distinguishes between a leader and a follower. There are two types of people who will tell you that you cannot make a difference in this world: those who are afraid to try and those who are afraid you will succeed. Thinking should become your capital asset, no matter whatever ups and downs you come across in your life. I find that the harder I work, the more luck I seem to have. The starting point of all achievement is desire. Success is the sum of small efforts, repeated day-in and day-out. If you want to achieve excellence, you can get there today. As of this second, quit doing less-than-excellent work. All progress takes place outside the comfort zone. You may only succeed if you desire succeeding; you may only fail if you do not mind failing. Courage is resistance to fear, mastery of fear - not absense of fear. Only put off until tomorrow what you are willing to die having left undone. People often say that motivation doesn't last. Well, neither does bathing - that's why we recommend it daily. We become what we think about most of the time, and that's the strangest secret. The only place where success comes before work is in the dictionary. The best reason to start an organization is to make meaning; to create a product or service to make the world a better place. I find that when you have a real interest in life and a curious life, that sleep is not the most important thing. It's not what you look at that matters, it's what you see. The road to success and the road to failure are almost exactly the same. The function of leadership is to produce more leaders, not more followers. Success is liking yourself, liking what you do, and liking how you do it. As we look ahead into the next century, leaders will be those who empower others. A real entrepreneur is somebody who has no safety net underneath them. The first step toward success is taken when you refuse to be a captive of the environment in which you first find yourself. People who succeed have momentum. The more they succeed, the more they want to succeed, and the more they find a way to succeed. Similarly, when someone is failing, the tendency is to get on a downward spiral that can even become a self-fulfilling prophecy. When I dare to be powerful - to use my strength in the service of my vision, then it becomes less and less important whether I am afraid. Whenever you find yourself on the side of the majority, it is time to pause and reflect. The successful warrior is the average man, with laser-like focus. Take up one idea. Make that one idea your life — think of it, dream of it, live on that idea. Let the brain, muscles, nerves, every part of your body, be full of that idea, and just leave every other idea alone. This is the way to success. Develop success from failures. Discouragement and failure are two of the surest stepping stones to success. If you don't design your own life plan, chances are you'll fall into someone else's plan. And guess what they have planned for you? Not much. If you genuinely want something, don't wait for it — teach yourself to be impatient. Don't let the fear of losing be greater than the excitement of winning. If you want to make a permanent change, stop focusing on the size of your problems and start focusing on the size of you! ~T. Harv Eker. You can't connect the dots looking forward; you can only connect them looking backwards. So you have to trust that the dots will somehow connect in your future. You have to trust in something - your gut, destiny, life, karma, whatever. This approach has never let me down, and it has made all the difference in my life. Successful people do what unsuccessful people are not willing to doDon't wish it were easier, wish you were better. The number one reason people fail in life is because they listen to their friends, family, and neighbors. The reason most people never reach their goals is that they don't define them, or ever seriously consider them as believable or achievable. Winners can tell you where they are going, what they plan to do along the way, and who will be sharing the adventure with them. In my experience, there is only one motivation, and that is desire. No reasons or principle contain it or stand against it. Success does not consist in never making mistakes but in never making the same one a second time. I don't want to get to the end of my life and find that I lived just the length of it. I want to have lived the width of it as well. You must expect great things of yourself before you can do them. Motivation is what gets you started. Habit is what keeps you going. People rarely succeed unless they have fun in what they are doing. There is no chance, no destiny, no fate, that can hinder or control the firm resolve of a determined soul. Our greatest fear should not be of failure but of succeeding at things in life that don't really matter. You've got to get up every morning with determination if you're going to go to bed with satisfaction. To be successful you must accept all challenges that come your way. You can't just accept the ones you like. Success is knowing your purpose in life, growing to reach your maximum potential, and sowing seeds that benefit others. Be miserable. Or motivate yourself. Whatever has to be done, it's always your choice. To accomplish great things, we must not only act, but also dream, not only plan, but also believe.~ Anatole France. Most of the important things in the world have been accomplished by people who have kept on trying when there seemed to be no help at all. You measure the size of the accomplishment by the obstacles you had to overcome to reach your goals. Real difficulties can be overcome; it is only the imaginary ones that are unconquerable. It is better to fail in originality than to succeed in imitation. Fortune sides with him who dares. Little minds are tamed and subdued by misfortune; but great minds rise above it. Failure is the condiment that gives success its flavor. Don't let what you cannot do interfere with what you can do. You may have to fight a battle more than once to win it. A man can be as great as he wants to be. If you believe in yourself and have the courage, the determination, the dedication, the competitive drive and if you are willing to sacrifice the little things in life and pay the price for the things that are worthwhile, it can be done. The first beam of light, that is life, Seeping through the overhead foliage, Giving dew drops the much suited luster. Birds chirping, grass hoppers leaping, It is near time, for her to be waking. The angelic charm, lazy eyes, With utter laziness, she opens her eyes. Sporting an aura, the angelic gleam, She looks brighter than the sunbeam. Ahead lies a chain of chores, Slowly she wakes up in her pinafore, Sipping from her cup of tea, enjoying the vista, A new day is just beginning, in the life of . The night is so cold with prevailing darkness, Deadly it feels, the blinding blackness. Sitting by the window, my mind as a canvas, Wisps of warm breath, fogging the glass. Oh! Light, the moonlight, shows its glaze, I see the clouds, changing their pace. Bright as heaven, the moon causes me to daze, Wonderful, so wonderful, akin to my sweetheart's face. The moon so beautiful, so is the moonlit night, So white, so bright, nature's work of art. Cease to be proud dear moon, despite your might, Brighter than you, is my sweetheart. I despise you for fearing the day, Running for cover, scared of the sun? There is someone I think of, night and day, So pretty, so bright, she'll cause you to stun. Miles, not tens, not hundreds, but thousands, Across the oceans, I have flown, To a nook, which is not my land, Hoping to realise my dreams, on my own. I often sit down, lost in thoughts, Sometimes in the town, watching civilians, Seasons changing, at times cold, sometimes hot, Often I wonder, why have I flown across the oceans. Home is where my heart is, there are no doubts, Wish I could be home, in the blink of an eye, I miss the one, who dominates my thoughts, Thinking of my home, of her, there I lie. Life, I try to get on with, often struggle, Life, I guess, acts like a martian, Memories, the good things, they make me chuckle, Back home will I fly one day, across the oceans. Juvenile, we were, when finding each other, Silly it seemed, the idea of being together. Months not years, the transition was swift, Before we knew, we had sworn, never between us, never, a rift. A lad, so young, I was, But of a genre, that no one was. A ring to bind us for eternity, I, in no time, turned it into reality. Hype, there was, encircling the ring, To me, it was more than just a circular thing. Who would dare to do such an act, No one but me, in fact. Days, nights and weeks passed, The wonderful day finally arrived. It was a heart throbbing moment, The ring changed hands in a second. Sweaty palms, excitement and fear was in the air,. As we were in a public transport, for which I even had paid a fare. Moments so sweet, joyful hearts full of love, We thanked together, the God above. That is the sweet story of the ring, Never will we forget, how it changed everything. Adorable, petite, shiny but aged, The ring adorns the perfect finger, immaculate. An ardent story, the ring bears, A story full of love, joy, fun and occasional tears. Blissful, blessed, complete we are together, So will it be, no matter what, forever, forever. Names so beautiful, names so many, Hundreds of them, blatantly sweet miscellany. As wonderful as her, the names she has. What could it be, behind the rove? All those names, aliases, all on the name of love. Often I portray myself as a clown, A rationale there is, not because I am down. Joyfully she beams, efforts not futile, I be the jester, just to see her smile. A smile so amiable, a smile so pleasant, There exists no one, to be her variant. Charming, alluring, frolicking and smart, A smile so wonderful, that forever, has captured my heart. It was a morning; tension was in the air, The exam was minutes away, which many thought was unfair. Together we were, on way to the exam hall, That’s when we stopped at the temple, in the mall. Prayers we chanted to the almighty, Circled slowly, seeking blessings quietly. Resembling seven vows, on the pavement of stone, Special we felt, though it was only one. Joyful we became, to the full glory, Even more special was that afternoon, which made history. Never would that afternoon, dim from my memory, For it was then, when happened, the ring’s story !. Sweaty foreheads, damp clothes and sticky weather, That was when we used to go to school together. Summer was taking its tall, the sun at its peak, We were all burning, akin to deep red steak. Problems, solutions, math and theories, The class was busy, but they weren’t one of my worries, For she used to be there, in the front as an eclipse, All I cared for was, not math, not physics, but catching a glimpse. How could I forget the divine noon, The courage I gathered, despite being a goon. On the stairs she was, the pretty lass, A foot below I stood up, kissed her cheek, Oh God! behind was the entire class! Red, did our faces turn, like a balloon, Oh, our wonderful, historical summer noon. Delightful akin to the pleasant spring morning, Eerie is how her beauty leaves, the vernal season withering. Epitome of affection and grace, heart so tender. Panache, splendid but gentle she adorns. A world without her for me, would be built of thorns. Today, I happened to awaken from a dream, A dream so refreshing, such joyous scenes. Like an angel among the stars, She, not once ceased to gleam in the class. Vague was the purpose, vague the motives, We were in the school, and folks seemed to notice. . . . It has been months since I came back to this, Sad, I cannot recollect the dream to furnish. Impossible it has become to complete this verse, The dream has been lost forever, in this never ending universe. Together we walked, leaving footprints on the wet sand. We moved along the shoal, stepping on water and land. Wind was making the drizzle merrily sway, fishing boats appeared as tiny spots far away. The riverside vegetation danced about on their stalks, I knew for sure, It was one of those unforgettable walks. We peeked inside the tumblers in the shop, staring at those lifeless creatures with gills, The sweet lass with utter curiosity, peeked at the fishes, trying not to dampen from the floor, her apparel’s frills. She lingered around me by the shore, while the man inside diced fishes. We stood there in the rain beside the river, by the palms and bushes. The evening sun was waning, dusk neared, Our hearts sank, for it was time to leave as the sky seared. It was one of those rare occasions we got to be together, Down the memory lane will they firmly stay, the shore, river, rain, us and the weather
"""


class BigReddy:
	"""This class generates pseudo-philosophical ramblings."""

	def __init__(self):
		"""Initialize."""
		self.model = markovify.Text(corpus)

	def ramble(self):
		"""Ramble."""
		return self.model.make_sentence()


def run():
	"""Generate a quote."""
	m = BigReddy()
	print(m.ramble())

if __name__ == "__main__":
	run()
